@@ -630,7 +630,7 @@ class Dataset:
     def remove_sheet_by_index(self, index: int):
         pass
 
-    def save(self, backup=True, row_height=0, col_width=0):
+    def save(self, *, backup=True, row_height=0, col_width=0):
         # make backup & delete
         if os.path.isfile(os.path.join(self.path, self.filename)) and backup:
             shutil.copy(os.path.join(self.path, self.filename), os.path.join(self.path, self.backup_name))
